@@ -8,7 +8,7 @@
 #pragma once
 
 #include <boost/spirit/include/qi.hpp>
-#include <boost/spirit/include/phoenix.hpp>
+#include <boost/phoenix.hpp>
 #include <svgpp/parser/detail/common.hpp>
 
 namespace svgpp
