@@ -23,7 +23,7 @@
 #include <svgpp/policy/value_events.hpp>
 #include <boost/mpl/pair.hpp>
 #include <boost/spirit/include/qi.hpp>
-#include <boost/spirit/include/phoenix.hpp>
+#include <boost/phoenix.hpp>
 
 namespace svgpp
 {
