@@ -7,7 +7,7 @@
 
 #pragma once
 
-#include <boost/parameter.hpp>
+#include <svgpp/utility/boost_parameter_fixed.hpp>
 #include <svgpp/template_parameters.hpp>
 
 namespace svgpp
@@ -16,4 +16,4 @@ namespace svgpp
 template<class ValueType, SVGPP_TEMPLATE_ARGS_DEF>
 struct value_parser;
 
-}
\ No newline at end of file
+}
