@@ -123,12 +123,10 @@ template<>              struct attribute_type<tag::element::glyphRef, tag::attri
 template<>              struct attribute_type<tag::element::glyphRef, tag::attribute::y           > { typedef tag::type::number type; };
 template<>              struct attribute_type<tag::element::glyphRef, tag::attribute::dx          > { typedef tag::type::number type; };
 template<>              struct attribute_type<tag::element::glyphRef, tag::attribute::dy          > { typedef tag::type::number type; };
-template<>              struct attribute_type<tag::element::fePointLight, tag::attribute::dx      > { typedef tag::type::number type; };
-template<>              struct attribute_type<tag::element::fePointLight, tag::attribute::dy      > { typedef tag::type::number type; };
+template<>              struct attribute_type<tag::element::fePointLight, tag::attribute::x       > { typedef tag::type::number type; };
+template<>              struct attribute_type<tag::element::fePointLight, tag::attribute::y       > { typedef tag::type::number type; };
 template<>              struct attribute_type<tag::element::feSpotLight, tag::attribute::x        > { typedef tag::type::number type; };
 template<>              struct attribute_type<tag::element::feSpotLight, tag::attribute::y        > { typedef tag::type::number type; };
-template<>              struct attribute_type<tag::element::feSpotLight, tag::attribute::dx       > { typedef tag::type::number type; };
-template<>              struct attribute_type<tag::element::feSpotLight, tag::attribute::dy       > { typedef tag::type::number type; };
 
 template<class Element> struct attribute_type<Element, tag::attribute::numOctaves>                { typedef tag::type::integer type; };
 template<class Element> struct attribute_type<Element, tag::attribute::targetX   >                { typedef tag::type::integer type; }; 
@@ -243,7 +241,7 @@ template<class Element> struct attribute_type<Element, tag::attribute::font>
 };
 
 /*
-font-face element attributes:
+'font-face' element attributes:
   font-size (Descriptor) Value:  	all | <length> [, <length>]*
   font-stretch = "all | [ normal | ultra-condensed | extra-condensed | condensed | semi-condensed | semi-expanded | expanded | extra-expanded | ultra-expanded] [, [ normal | ultra-condensed | extra-condensed | condensed | semi-condensed | semi-expanded | expanded | extra-expanded | ultra-expanded] ]*"
   font-style = "all | [ normal | italic | oblique] [, [normal | italic | oblique]]*"
@@ -259,7 +257,7 @@ glyph-name = "<name> [, <name> ]* "
 keySplines = "<list>"
 keyTimes = "<list>"
 panose-1 = "[<integer>]{10}"
-values = "<list>" // animate, animateColor, animateMotion, animateTransform
+values = "<list>" // 'animate', 'animateColor', 'animateMotion', 'animateTransform'
 */
 
 template<class Element> struct attribute_type<Element, tag::attribute::baseline_shift> 
@@ -463,4 +461,4 @@ template<class Element> struct attribute_type<Element, tag::attribute::xml::lang
 template<>              struct attribute_type<tag::element::script, tag::attribute::type     > { typedef tag::type::string type; };
 template<>              struct attribute_type<tag::element::style, tag::attribute::type      > { typedef tag::type::string type; };
 
-}}
\ No newline at end of file
+}}
