@@ -21,5 +21,5 @@ public:
 
 private:
   class Impl;
-  std::auto_ptr<Impl> impl_;
-};
\ No newline at end of file
+  std::unique_ptr<Impl> impl_;
+};
