@@ -626,7 +626,7 @@ private:
   Document & document_;
   ImageBuffer * const image_buffer_; // Non-NULL only for topmost SVG element
   lazy_buffer_t parent_buffer_;
-  std::auto_ptr<ImageBuffer> own_buffer_;
+  std::unique_ptr<ImageBuffer> own_buffer_;
   boost::shared_ptr<ClipBuffer> clip_buffer_;
   length_factory_t length_factory_;
   bool rendering_disabled_;
@@ -1656,7 +1656,10 @@ void renderDocument(XMLDocument & xmlDocument, ImageBuffer & buffer)
 {
   Document document(xmlDocument);
   Canvas canvas(document, buffer);
-  document_traversal_main::load_document(xmlDocument.getRoot(), canvas);
+  if (XMLElement root = xmlDocument.getRoot())
+    document_traversal_main::load_document(root, canvas);
+  else
+    throw std::runtime_error("No root XML element");
 }
 
 int main(int argc, char * argv[])
@@ -1731,4 +1734,4 @@ int main(int argc, char * argv[])
 #endif
 
   return 0;
-}
\ No newline at end of file
+}
